BOOST_PP_TUPLE_REM_CTOR

The BOOST_PP_TUPLE_REM_CTOR macro removes the parentheses from a tuple.

#### Usage

BOOST_PP_TUPLE_REM_CTOR(size, tuple)
or
BOOST_PP_TUPLE_REM_CTOR(...) (v)

#### Arguments

size
  The size of the tuple from which the parentheses are to be removed. Valid tuple sizes range from 1 to BOOST_PP_LIMIT_TUPLE.
tuple
  The tuple from which the parenthesis are removed.

#### Remarks

The size argument must be the actual size of tuple.
You can invoke the variadic version (v) as BOOST_PP_TUPLE_REM_CTOR(tuple) or BOOST_PP_TUPLE_REM_CTOR(size,tuple).

#### See Also

- BOOST_PP_LIMIT_TUPLE

#### Requirements

Header: <boost/preprocessor/tuple/rem.hpp>

#### Sample Code

    #include <boost/preprocessor/tuple/rem.hpp>

    BOOST_PP_TUPLE_REM_CTOR(3, (x, y, z)) // expands to x, y, z

    // or for the variadic version (v)

    BOOST_PP_TUPLE_REM_CTOR((x, y, z)) // expands to x, y, z

© Copyright Housemarque Oy 2002
© Copyright Paul Mensonides 2002
© Copyright Edward Diener 2011,2013

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)